summaryrefslogtreecommitdiffstats
path: root/src/document
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:33:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:33:46 -0600
commit4faf11eccc5f08d2aa0540157d6eff80b7cdb02a (patch)
tree19bc4d69423c21bcde8ac0cb6fcb11146ae19137 /src/document
parente6d6692eda797b10f322a83ffdcf23fca719709e (diff)
downloadrosegarden-4faf11eccc5f08d2aa0540157d6eff80b7cdb02a.tar.gz
rosegarden-4faf11eccc5f08d2aa0540157d6eff80b7cdb02a.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'src/document')
-rw-r--r--src/document/MultiViewCommandHistory.cpp8
-rw-r--r--src/document/MultiViewCommandHistory.h2
-rw-r--r--src/document/RoseXmlHandler.cpp16
-rw-r--r--src/document/RosegardenGUIDoc.cpp56
-rw-r--r--src/document/RosegardenGUIDoc.h6
-rw-r--r--src/document/io/HydrogenXMLHandler.cpp6
-rw-r--r--src/document/io/LilyPondExporter.cpp36
-rw-r--r--src/document/io/RG21Loader.cpp28
-rw-r--r--src/document/io/RG21Loader.h2
9 files changed, 80 insertions, 80 deletions
diff --git a/src/document/MultiViewCommandHistory.cpp b/src/document/MultiViewCommandHistory.cpp
index a987f0f..7e529fb 100644
--- a/src/document/MultiViewCommandHistory.cpp
+++ b/src/document/MultiViewCommandHistory.cpp
@@ -325,9 +325,9 @@ MultiViewCommandHistory::updateButton(bool undo,
commandName.replace(TQRegExp("&"), "");
commandName.replace(TQRegExp("\\.\\.\\.$"), "");
if (undo)
- text = i18n("Und&o %1").tqarg(commandName);
+ text = i18n("Und&o %1").arg(commandName);
else
- text = i18n("Re&do %1").tqarg(commandName);
+ text = i18n("Re&do %1").arg(commandName);
action->setText(text);
}
}
@@ -369,9 +369,9 @@ MultiViewCommandHistory::updateMenu(bool undo,
TQString text;
if (undo)
- text = i18n("Und&o %1").tqarg(commandName);
+ text = i18n("Und&o %1").arg(commandName);
else
- text = i18n("Re&do %1").tqarg(commandName);
+ text = i18n("Re&do %1").arg(commandName);
menu->insertItem(text, j++);
}
diff --git a/src/document/MultiViewCommandHistory.h b/src/document/MultiViewCommandHistory.h
index e3c902e..5341f56 100644
--- a/src/document/MultiViewCommandHistory.h
+++ b/src/document/MultiViewCommandHistory.h
@@ -113,7 +113,7 @@ signals:
* (whether by addCommand, undo or redo).
*
* It should be connected to the update() slot of widgets
- * which need to tqrepaint after a command
+ * which need to repaint after a command
*/
void commandExecuted();
diff --git a/src/document/RoseXmlHandler.cpp b/src/document/RoseXmlHandler.cpp
index ea49839..87ed1f6 100644
--- a/src/document/RoseXmlHandler.cpp
+++ b/src/document/RoseXmlHandler.cpp
@@ -439,7 +439,7 @@ RoseXmlHandler::startElement(const TQString& namespaceURI,
int minor = sminor.toInt();
if (major > RosegardenGUIDoc::FILE_FORMAT_VERSION_MAJOR) {
- m_errorString = i18n("This file was written by Rosegarden %1, and it uses\na different file format that cannot be read by this version.").tqarg(version);
+ m_errorString = i18n("This file was written by Rosegarden %1, and it uses\na different file format that cannot be read by this version.").arg(version);
return false;
}
@@ -449,7 +449,7 @@ RoseXmlHandler::startElement(const TQString& namespaceURI,
CurrentProgressDialog::freeze();
KStartupLogo::hideIfStillThere();
- KMessageBox::information(0, i18n("This file was written by Rosegarden %1, which is more recent than this version.\nThere may be some incompatibilities with the file format.").tqarg(version));
+ KMessageBox::information(0, i18n("This file was written by Rosegarden %1, which is more recent than this version.\nThere may be some incompatibilities with the file format.").arg(version));
CurrentProgressDialog::thaw();
}
@@ -2200,9 +2200,9 @@ bool
RoseXmlHandler::error(const TQXmlParseException& exception)
{
m_errorString = TQString("%1 at line %2, column %3")
- .tqarg(exception.message())
- .tqarg(exception.lineNumber())
- .tqarg(exception.columnNumber());
+ .arg(exception.message())
+ .arg(exception.lineNumber())
+ .arg(exception.columnNumber());
return TQXmlDefaultHandler::error( exception );
}
@@ -2210,9 +2210,9 @@ bool
RoseXmlHandler::fatalError(const TQXmlParseException& exception)
{
m_errorString = TQString("%1 at line %2, column %3")
- .tqarg(exception.message())
- .tqarg(exception.lineNumber())
- .tqarg(exception.columnNumber());
+ .arg(exception.message())
+ .arg(exception.lineNumber())
+ .arg(exception.columnNumber());
return TQXmlDefaultHandler::fatalError( exception );
}
diff --git a/src/document/RosegardenGUIDoc.cpp b/src/document/RosegardenGUIDoc.cpp
index 2e7a3ae..784c8fc 100644
--- a/src/document/RosegardenGUIDoc.cpp
+++ b/src/document/RosegardenGUIDoc.cpp
@@ -107,7 +107,7 @@
#include <tqobject.h>
#include <tqstring.h>
#include <tqstringlist.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqwidget.h>
#include "gui/widgets/ProgressBar.h"
@@ -229,7 +229,7 @@ void RosegardenGUIDoc::slotUpdateAllViews(RosegardenGUIView *sender)
for (w = m_viewList.first(); w != 0; w = m_viewList.next()) {
if (w != sender)
- w->tqrepaint();
+ w->repaint();
}
}
@@ -239,7 +239,7 @@ void RosegardenGUIDoc::setModified(bool m)
RG_DEBUG << "RosegardenGUIDoc[" << this << "]::setModified(" << m << ")\n";
}
-void RosegardenGUIDoc::clearModifiedtqStatus()
+void RosegardenGUIDoc::clearModifiedStatus()
{
setModified(false);
setAutoSaved(true);
@@ -349,10 +349,10 @@ bool RosegardenGUIDoc::saveIfModified()
if (!completed) {
if (!errMsg.isNull()) {
KMessageBox::error(0, i18n(TQString("Could not save document at %1\n(%2)")
- .tqarg(getAbsFilePath()).tqarg(errMsg).ascii()));
+ .arg(getAbsFilePath()).arg(errMsg).ascii()));
} else {
KMessageBox::error(0, i18n(TQString("Could not save document at %1")
- .tqarg(getAbsFilePath()).ascii()));
+ .arg(getAbsFilePath()).ascii()));
}
}
}
@@ -463,7 +463,7 @@ RosegardenGUIDoc::deleteOrphanedAudioFiles(bool documentWillNotBeSaved)
if (!file.remove()) {
std::cerr << "WARNING: Failed to remove orphaned derived audio file \"" << derivedOrphans[i].ascii() << std::endl;
}
- TQFile peakFile(TQString("%1.pk").tqarg(derivedOrphans[i]));
+ TQFile peakFile(TQString("%1.pk").arg(derivedOrphans[i]));
peakFile.remove();
}
@@ -523,10 +523,10 @@ RosegardenGUIDoc::deleteOrphanedAudioFiles(bool documentWillNotBeSaved)
TQFile file(recordedOrphans[i]);
if (!file.remove()) {
KMessageBox::error(0, i18n("File %1 could not be deleted.")
- .tqarg(recordedOrphans[i]));
+ .arg(recordedOrphans[i]));
}
- TQFile peakFile(TQString("%1.pk").tqarg(recordedOrphans[i]));
+ TQFile peakFile(TQString("%1.pk").arg(recordedOrphans[i]));
peakFile.remove();
}
}
@@ -577,7 +577,7 @@ bool RosegardenGUIDoc::openDocument(const TQString& filename,
// Check if file readable with fileInfo ?
if (!fileInfo.isReadable() || fileInfo.isDir()) {
KStartupLogo::hideIfStillThere();
- TQString msg(i18n("Can't open file '%1'").tqarg(filename));
+ TQString msg(i18n("Can't open file '%1'").arg(filename));
KMessageBox::sorry(0, msg);
return false;
}
@@ -639,8 +639,8 @@ bool RosegardenGUIDoc::openDocument(const TQString& filename,
if (!okay) {
KStartupLogo::hideIfStillThere();
TQString msg(i18n("Error when parsing file '%1': \"%2\"")
- .tqarg(filename)
- .tqarg(errMsg));
+ .arg(filename)
+ .arg(errMsg));
CurrentProgressDialog::freeze();
KMessageBox::sorry(0, msg);
@@ -1152,7 +1152,7 @@ bool RosegardenGUIDoc::saveDocument(const TQString& filename,
int status = temp.status();
if (status != 0) {
- errMsg = i18n(TQString("Could not create temporary file in directory of '%1': %2").tqarg(filename).tqarg(strerror(status)).ascii());
+ errMsg = i18n(TQString("Could not create temporary file in directory of '%1': %2").arg(filename).arg(strerror(status)).ascii());
return false;
}
@@ -1164,7 +1164,7 @@ bool RosegardenGUIDoc::saveDocument(const TQString& filename,
if (!temp.close()) {
status = temp.status();
errMsg = i18n(TQString("Failure in temporary file handling for file '%1': %2")
- .tqarg(tempFileName).tqarg(strerror(status)).ascii());
+ .arg(tempFileName).arg(strerror(status)).ascii());
return false;
}
@@ -1177,7 +1177,7 @@ bool RosegardenGUIDoc::saveDocument(const TQString& filename,
TQDir dir(TQFileInfo(tempFileName).dir());
if (!dir.rename(tempFileName, filename)) {
- errMsg = i18n(TQString("Failed to rename temporary output file '%1' to desired output file '%2'").tqarg(tempFileName).tqarg(filename).ascii());
+ errMsg = i18n(TQString("Failed to rename temporary output file '%1' to desired output file '%2'").arg(tempFileName).arg(filename).ascii());
return false;
}
@@ -1198,7 +1198,7 @@ bool RosegardenGUIDoc::saveDocumentActual(const TQString& filename,
if (!rc) {
// do some error report
- errMsg = i18n(TQString("Could not open file '%1' for writing").tqarg(filename).ascii());
+ errMsg = i18n(TQString("Could not open file '%1' for writing").arg(filename).ascii());
delete fileCompressedDevice;
return false; // couldn't open file
}
@@ -1283,11 +1283,11 @@ bool RosegardenGUIDoc::saveDocumentActual(const TQString& filename,
TQString triggerAtts = TQString
("triggerid=\"%1\" triggerbasepitch=\"%2\" triggerbasevelocity=\"%3\" triggerretune=\"%4\" triggeradjusttimes=\"%5\" ")
- .tqarg((*ci)->getId())
- .tqarg((*ci)->getBasePitch())
- .tqarg((*ci)->getBaseVelocity())
- .tqarg((*ci)->getDefaultRetune())
- .tqarg(strtoqstr((*ci)->getDefaultTimeAdjust()));
+ .arg((*ci)->getId())
+ .arg((*ci)->getBasePitch())
+ .arg((*ci)->getBaseVelocity())
+ .arg((*ci)->getDefaultRetune())
+ .arg(strtoqstr((*ci)->getDefaultTimeAdjust()));
Segment *segment = (*ci)->getSegment();
saveSegment(outStream, segment, progress, totalEvents, eventCount, triggerAtts);
@@ -1315,7 +1315,7 @@ bool RosegardenGUIDoc::saveDocumentActual(const TQString& filename,
// check that all went ok
//
if (fileCompressedDevice->status() != IO_Ok) {
- errMsg = i18n(TQString("Error while writing on '%1'").tqarg(filename).ascii());
+ errMsg = i18n(TQString("Error while writing on '%1'").arg(filename).ascii());
delete fileCompressedDevice;
return false;
}
@@ -1380,8 +1380,8 @@ void RosegardenGUIDoc::saveSegment(TQTextStream& outStream, Segment *segment,
TQString time;
outStream << TQString("<segment track=\"%1\" start=\"%2\" ")
- .tqarg(segment->getTrack())
- .tqarg(segment->getStartTime());
+ .arg(segment->getTrack())
+ .arg(segment->getStartTime());
if (!extraAttributes.isNull())
outStream << extraAttributes << " ";
@@ -1612,7 +1612,7 @@ RosegardenGUIDoc::xmlParse(TQString fileContents, TQString &errMsg,
} else {
if (getSequenceManager() &&
- !(getSequenceManager()->getSoundDrivertqStatus() & AUDIO_OK)) {
+ !(getSequenceManager()->getSoundDriverStatus() & AUDIO_OK)) {
KStartupLogo::hideIfStillThere();
CurrentProgressDialog::freeze();
@@ -1662,7 +1662,7 @@ RosegardenGUIDoc::xmlParse(TQString fileContents, TQString &errMsg,
KStartupLogo::hideIfStillThere();
CurrentProgressDialog::freeze();
- KMessageBox::information(0, i18n("<h3>Incorrect audio sample rate</h3><p>This composition contains audio files that were recorded or imported with the audio server running at a different sample rate (%1 Hz) from the current JACK server sample rate (%2 Hz).</p><p>Rosegarden will play this composition at the correct speed, but any audio files in it will probably sound awful.</p><p>Please consider re-starting the JACK server at the correct rate (%3 Hz) and re-loading this composition before you do any more work with it.</p>").tqarg(er).tqarg(sr).tqarg(er));
+ KMessageBox::information(0, i18n("<h3>Incorrect audio sample rate</h3><p>This composition contains audio files that were recorded or imported with the audio server running at a different sample rate (%1 Hz) from the current JACK server sample rate (%2 Hz).</p><p>Rosegarden will play this composition at the correct speed, but any audio files in it will probably sound awful.</p><p>Please consider re-starting the JACK server at the correct rate (%3 Hz) and re-loading this composition before you do any more work with it.</p>").arg(er).arg(sr).arg(er));
CurrentProgressDialog::thaw();
shownWarning = true;
@@ -1672,7 +1672,7 @@ RosegardenGUIDoc::xmlParse(TQString fileContents, TQString &errMsg,
KStartupLogo::hideIfStillThere();
CurrentProgressDialog::freeze();
- KMessageBox::information(0, i18n("<h3>Inconsistent audio sample rates</h3><p>This composition contains audio files at more than one sample rate.</p><p>Rosegarden will play them at the correct speed, but any audio files that were recorded or imported at rates different from the current JACK server sample rate (%1 Hz) will probably sound awful.</p><p>Please see the audio file manager dialog for more details, and consider resampling any files that are at the wrong rate.</p>").tqarg(sr),
+ KMessageBox::information(0, i18n("<h3>Inconsistent audio sample rates</h3><p>This composition contains audio files at more than one sample rate.</p><p>Rosegarden will play them at the correct speed, but any audio files that were recorded or imported at rates different from the current JACK server sample rate (%1 Hz) will probably sound awful.</p><p>Please see the audio file manager dialog for more details, and consider resampling any files that are at the wrong rate.</p>").arg(sr),
i18n("Inconsistent sample rates"),
"file-load-inconsistent-samplerates");
@@ -1695,7 +1695,7 @@ RosegardenGUIDoc::xmlParse(TQString fileContents, TQString &errMsg,
TQString type, soName, label;
PluginIdentifier::parseIdentifier(ident, type, soName, label);
TQString pluginFileName = TQFileInfo(soName).fileName();
- msg += i18n("<li>%1 (from %2)</li>").tqarg(label).tqarg(pluginFileName);
+ msg += i18n("<li>%1 (from %2)</li>").arg(label).arg(pluginFileName);
}
msg += "</ul>";
@@ -2557,7 +2557,7 @@ RosegardenGUIDoc::addRecordMIDISegment(TrackId tid)
} else {
label = track->getLabel();
}
- label = qstrtostr(i18n("%1 (recorded)").tqarg(strtoqstr(label)));
+ label = qstrtostr(i18n("%1 (recorded)").arg(strtoqstr(label)));
}
recordMIDISegment->setLabel(label);
diff --git a/src/document/RosegardenGUIDoc.h b/src/document/RosegardenGUIDoc.h
index 1218673..c2b348d 100644
--- a/src/document/RosegardenGUIDoc.h
+++ b/src/document/RosegardenGUIDoc.h
@@ -147,7 +147,7 @@ protected:
* action on the view connected to the document.
*
* this is just an accessor, other components should call
- * slotDocumentModified() and clearModifiedtqStatus() instead of
+ * slotDocumentModified() and clearModifiedStatus() instead of
* this method, which perform all the related housework.
*
*/
@@ -164,7 +164,7 @@ public:
* clears the 'modified' status of the document (sets it back to false).
*
*/
- void clearModifiedtqStatus();
+ void clearModifiedStatus();
/**
* "save modified" - asks the user for saving if the document is
@@ -447,7 +447,7 @@ public:
public slots:
/**
- * calls tqrepaint() on all views connected to the document object
+ * calls repaint() on all views connected to the document object
* and is called by the view by which the document has been
* changed. As this view normally repaints itself, it is excluded
* from the paintEvent.
diff --git a/src/document/io/HydrogenXMLHandler.cpp b/src/document/io/HydrogenXMLHandler.cpp
index 565fe6d..9854648 100644
--- a/src/document/io/HydrogenXMLHandler.cpp
+++ b/src/document/io/HydrogenXMLHandler.cpp
@@ -272,9 +272,9 @@ HydrogenXMLHandler::endElement(const TQString& /*namespaceURI*/,
// whole bar unit segment.
//
m_segment->setEndMarkerTime(m_composition->getBarEnd(m_currentBar));
- TQString label = TQString("%1 - %2 %3 %4").tqarg(strtoqstr(m_patternName))
- .tqarg(strtoqstr(m_sequenceName))
- .tqarg(i18n(" imported from Hydrogen ")).tqarg(strtoqstr(m_version));
+ TQString label = TQString("%1 - %2 %3 %4").arg(strtoqstr(m_patternName))
+ .arg(strtoqstr(m_sequenceName))
+ .arg(i18n(" imported from Hydrogen ")).arg(strtoqstr(m_version));
m_segment->setLabel(qstrtostr(label));
m_composition->addTrack(track);
diff --git a/src/document/io/RG21Loader.cpp b/src/document/io/RG21Loader.cpp
index c36a228..7f6d7ea 100644
--- a/src/document/io/RG21Loader.cpp
+++ b/src/document/io/RG21Loader.cpp
@@ -42,7 +42,7 @@
#include <tqobject.h>
#include <tqstring.h>
#include <tqstringlist.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <string>
#include <vector>
@@ -69,7 +69,7 @@ RG21Loader::RG21Loader(Studio *studio,
m_currentClef(Clef::Treble),
m_currentInstrumentId(MidiInstrumentBase),
m_inGroup(false),
- m_tietqStatus(0),
+ m_tieStatus(0),
m_nbStaves(0)
{}
@@ -106,8 +106,8 @@ bool RG21Loader::parseKey()
}
TQString keyName = TQString("%1 %2or")
- .tqarg(keyBase)
- .tqarg(m_tokens[3].lower());
+ .arg(keyBase)
+ .arg(m_tokens[3].lower());
m_currentKey = Rosegarden::Key(qstrtostr(keyName));
Event *keyEvent = m_currentKey.getAsEvent(m_currentSegmentTime);
@@ -173,10 +173,10 @@ bool RG21Loader::parseChordItem()
noteEvent->set
<Int>(PITCH, pitch);
- if (m_tietqStatus == 1) {
+ if (m_tieStatus == 1) {
noteEvent->set
<Bool>(TIED_FORWARD, true);
- } else if (m_tietqStatus == 2) {
+ } else if (m_tieStatus == 2) {
noteEvent->set
<Bool>(TIED_BACKWARD, true);
}
@@ -199,10 +199,10 @@ bool RG21Loader::parseChordItem()
}
m_currentSegmentTime += duration;
- if (m_tietqStatus == 2)
- m_tietqStatus = 0;
- else if (m_tietqStatus == 1)
- m_tietqStatus = 2;
+ if (m_tieStatus == 2)
+ m_tieStatus = 0;
+ else if (m_tieStatus == 1)
+ m_tieStatus = 2;
return true;
}
@@ -348,13 +348,13 @@ bool RG21Loader::parseIndicationStart()
if (indicationType == "tie") {
- if (m_tietqStatus != 0) {
+ if (m_tieStatus != 0) {
RG_DEBUG
<< "RG21Loader:: parseIndicationStart: WARNING: Found tie within "
<< "tie, ignoring" << endl;
return true;
}
- // m_tietqStatus = 1;
+ // m_tieStatus = 1;
Segment::iterator i = m_currentSegment->end();
if (i != m_currentSegment->begin()) {
@@ -368,7 +368,7 @@ bool RG21Loader::parseIndicationStart()
--i;
}
}
- m_tietqStatus = 2;
+ m_tieStatus = 2;
RG_DEBUG << "rg21io: Indication start: it's a tie" << endl;
@@ -484,7 +484,7 @@ void RG21Loader::closeGroup()
// To change the time of an event, we need to erase &
// re-insert it. But erasure will delete the event, and
- // if it's an indication event that will tqinvalidate our
+ // if it's an indication event that will invalidate our
// indicationsExtant entry. Hence this unpleasantness:
if ((*i)->isa(Indication::EventType)) {
diff --git a/src/document/io/RG21Loader.h b/src/document/io/RG21Loader.h
index 236d6c6..583367c 100644
--- a/src/document/io/RG21Loader.h
+++ b/src/document/io/RG21Loader.h
@@ -145,7 +145,7 @@ protected:
int m_groupUntupledLength;
int m_groupUntupledCount;
- int m_tietqStatus; // 0 -> none, 1 -> tie started, 2 -> seen one note
+ int m_tieStatus; // 0 -> none, 1 -> tie started, 2 -> seen one note
TQString m_currentLine;
TQString m_currentStaffName;
diff --git a/src/document/io/LilyPondExporter.cpp b/src/document/io/LilyPondExporter.cpp
index 3c18d41..f3d1ba8 100644
--- a/src/document/io/LilyPondExporter.cpp
+++ b/src/document/io/LilyPondExporter.cpp
@@ -72,7 +72,7 @@
#include <tqobject.h>
#include <tqregexp.h>
#include <tqstring.h>
-#include <tqtextcodec.h>
+#include <textcodec.h>
#include <kapplication.h>
#include <sstream>
#include <algorithm>
@@ -137,7 +137,7 @@ LilyPondExporter::readConfigVariables(void)
m_exportBeams = cfg->readBoolEntry("lilyexportbeamings", false);
m_exportStaffMerge = cfg->readBoolEntry("lilyexportstaffmerge", false);
m_exportStaffGroup = cfg->readBoolEntry("lilyexportstaffbrackets", true);
- m_lyricsHAlignment = cfg->readBoolEntry("lilylyricshtqalignment", LEFT_ALIGN);
+ m_lyricsHAlignment = cfg->readBoolEntry("lilylyricshalignment", LEFT_ALIGN);
m_languageLevel = cfg->readUnsignedNumEntry("lilylanguage", LILYPOND_VERSION_2_6);
m_exportMarkerMode = cfg->readUnsignedNumEntry("lilyexportmarkermode", EXPORT_NO_MARKERS );
@@ -402,7 +402,7 @@ LilyPondExporter::write()
CurrentProgressDialog::freeze();
int reply = KMessageBox::warningContinueCancel(
0, i18n("LilyPond does not allow spaces or backslashes in filenames.\n\n"
- "Would you like to use\n\n %1\n\n instead?").tqarg(baseName));
+ "Would you like to use\n\n %1\n\n instead?").arg(baseName));
if (reply != KMessageBox::Continue)
return false;
}
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
// set indention level to make future changes to horizontal tqlayout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;
@@ -583,7 +583,7 @@ LilyPondExporter::write()
// bind staffs with or without staff group bracket
str << indent(col) // indent
<< "<<" << " s4 " << ">>" << std::endl;
- str << indent(col) << "\\tqlayout { }" << std::endl;
+ str << indent(col) << "\\layout { }" << std::endl;
str << indent(--col) << "}" << std::endl;
return true;
}
@@ -1202,13 +1202,13 @@ LilyPondExporter::write()
str << indent(col) << "\\lyricsto \"" << voiceNumber.str() << "\""
<< " \\new Lyrics \\lyricmode {" << std::endl;
if (m_lyricsHAlignment == RIGHT_ALIGN) {
- str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #RIGHT"
+ str << indent(++col) << "\\override LyricText #'self-alignment-X = #RIGHT"
<< std::endl;
} else if (m_lyricsHAlignment == CENTER_ALIGN) {
- str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #CENTER"
+ str << indent(++col) << "\\override LyricText #'self-alignment-X = #CENTER"
<< std::endl;
} else {
- str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #LEFT"
+ str << indent(++col) << "\\override LyricText #'self-alignment-X = #LEFT"
<< std::endl;
}
str << indent(col) << "\\set ignoreMelismata = ##t" << std::endl;
@@ -1253,8 +1253,8 @@ LilyPondExporter::write()
str << std::endl << indent(--col) << ">> % notes" << std::endl << std::endl; // indent-
// str << std::endl << indent(col) << ">> % global wrapper" << std::endl;
- // write \tqlayout block
- str << indent(col) << "\\tqlayout { }" << std::endl;
+ // write \layout block
+ str << indent(col) << "\\layout { }" << std::endl;
// write initial tempo in Midi block, if user wishes (added per user request...
// makes debugging the .ly file easier because fewer "noisy" errors are
@@ -1430,7 +1430,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += note.getDuration();
durationRatio = writeSkip(timeSignature, 0, note.getDuration(), true, str);
durationRatioSum = fractionSum(durationRatioSum,durationRatio);
- // str << qstrtostr(TQString(" %{ %1/%2 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 %} ").arg(durationRatio.first).arg(durationRatio.second)); // DEBUG
}
timeT prevDuration = -1;
@@ -1496,7 +1496,7 @@ LilyPondExporter::writeBar(Segment *s,
groupId = -1;
groupType = "";
} else {
- startGroupBeamingsStr += TQString("\\times %1/%2 { ").tqarg(numerator).tqarg(denominator);
+ startGroupBeamingsStr += TQString("\\times %1/%2 { ").arg(numerator).arg(denominator);
tupletRatio = std::pair<int, int>(numerator, denominator);
// Require explicit beamed groups,
// fixes bug #1683205.
@@ -1688,7 +1688,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += soundingDuration;
std::pair<int,int> ratio = fractionProduct(durationRatio,tupletRatio);
durationRatioSum = fractionSum(durationRatioSum, ratio);
- // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second).tqarg(tupletRatio.first).tqarg(tupletRatio.second).tqarg(ratio.first).tqarg(ratio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").arg(durationRatio.first).arg(durationRatio.second).arg(tupletRatio.first).arg(tupletRatio.second).arg(ratio.first).arg(ratio.second)); // DEBUG
std::vector<Mark> marks(chord.getMarksForChord());
// problem here: stem direction unavailable (it's a view-local property)
@@ -1869,7 +1869,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += soundingDuration;
std::pair<int,int> ratio = fractionProduct(durationRatio,tupletRatio);
durationRatioSum = fractionSum(durationRatioSum, ratio);
- // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second).tqarg(tupletRatio.first).tqarg(tupletRatio.second).tqarg(ratio.first).tqarg(ratio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").arg(durationRatio.first).arg(durationRatio.second).arg(tupletRatio.first).arg(tupletRatio.second).arg(ratio.first).arg(ratio.second)); // DEBUG
} else if ((*i)->isa(Clef::EventType)) {
try {
@@ -1992,16 +1992,16 @@ LilyPondExporter::writeBar(Segment *s,
str << "c:" << barreStart << "-" << barreEnd << "-" << barreFret << ";";
}
- if (fingering.getStringtqStatus( 6-stringNum ) == Guitar::Fingering::MUTED) {
+ if (fingering.getStringStatus( 6-stringNum ) == Guitar::Fingering::MUTED) {
str << stringNum << "-x;";
- } else if (fingering.getStringtqStatus( 6-stringNum ) == Guitar::Fingering::OPEN) {
+ } else if (fingering.getStringStatus( 6-stringNum ) == Guitar::Fingering::OPEN) {
str << stringNum << "-o;";
} else {
- int stringtqStatus = fingering.getStringtqStatus(6-stringNum);
+ int stringStatus = fingering.getStringStatus(6-stringNum);
if ((stringNum <= barreStart) && (stringNum >= barreEnd)) {
str << stringNum << "-" << barreFret << ";";
} else {
- str << stringNum << "-" << stringtqStatus << ";";
+ str << stringNum << "-" << stringStatus << ";";
}
}
}
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
- // set indention level to make future changes to horizontal tqlayout less
+ // set indention level to make future changes to horizontal layout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;